==> haskell-hledger-lib_1.10.orig.tar.gz: hledger-lib-1.10/Hledger/Data.hs <==
{-|

The Hledger.Data library allows parsing and querying of C++ ledger-style
journal files.  It generally provides a compatible subset of C++ ledger's
functionality.  This package re-exports all the Hledger.Data.* modules
(except UTF8, which requires an explicit import.)

-}

module Hledger.Data (
               module Hledger.Data.Account,
               module Hledger.Data.AccountName,
               module Hledger.Data.Amount,
               module Hledger.Data.Commodity,
               module Hledger.Data.Dates,
               module Hledger.Data.Journal,
               module Hledger.Data.Ledger,
               module Hledger.Data.MarketPrice,
               module Hledger.Data.Period,
               module Hledger.Data.Posting,
               module Hledger.Data.RawOptions,
               module Hledger.Data.StringFormat,
               module Hledger.Data.Timeclock,
               module Hledger.Data.Transaction,
               module Hledger.Data.AutoTransaction,
               module Hledger.Data.Types,
               tests_Hledger_Data
              )
where
import Test.HUnit

import Hledger.Data.Account
import Hledger.Data.AccountName
import Hledger.Data.Amount
import Hledger.Data.Commodity
import Hledger.Data.Dates
import Hledger.Data.Journal
import Hledger.Data.Ledger
import Hledger.Data.MarketPrice
import Hledger.Data.Period
import Hledger.Data.Posting
import Hledger.Data.RawOptions
import Hledger.Data.StringFormat
import Hledger.Data.Timeclock
import Hledger.Data.Transaction
import Hledger.Data.AutoTransaction
import Hledger.Data.Types

tests_Hledger_Data :: Test
tests_Hledger_Data = TestList
    [
     tests_Hledger_Data_Account
    ,tests_Hledger_Data_AccountName
    ,tests_Hledger_Data_Amount
    ,tests_Hledger_Data_Commodity
    ,tests_Hledger_Data_Journal
    ,tests_Hledger_Data_MarketPrice
    ,tests_Hledger_Data_Ledger
    ,tests_Hledger_Data_Posting
    -- ,tests_Hledger_Data_RawOptions
    -- ,tests_Hledger_Data_StringFormat
    ,tests_Hledger_Data_Timeclock
    ,tests_Hledger_Data_Transaction
    -- ,tests_Hledger_Data_Types
    ]

==> haskell-hledger-lib_1.12.orig.tar.gz: hledger-lib-1.12/Hledger/Data.hs <==
{-# LANGUAGE OverloadedStrings #-}
{-|

The Hledger.Data library allows parsing and querying of C++ ledger-style
journal files.  It generally provides a compatible subset of C++ ledger's
functionality.  This package re-exports all the Hledger.Data.* modules
(except UTF8, which requires an explicit import.)

-}

module Hledger.Data (
               module Hledger.Data.Account,
               module Hledger.Data.AccountName,
               module Hledger.Data.Amount,
               module Hledger.Data.Commodity,
               module Hledger.Data.Dates,
               module Hledger.Data.Journal,
               module Hledger.Data.Ledger,
               module Hledger.Data.MarketPrice,
               module Hledger.Data.Period,
               module Hledger.Data.PeriodicTransaction,
               module Hledger.Data.Posting,
               module Hledger.Data.RawOptions,
               module Hledger.Data.StringFormat,
               module Hledger.Data.Timeclock,
               module Hledger.Data.Transaction,
               module Hledger.Data.TransactionModifier,
               module Hledger.Data.Types,
               tests_Data
              )
where

import Hledger.Data.Account
import Hledger.Data.AccountName
import Hledger.Data.Amount
import Hledger.Data.Commodity
import Hledger.Data.Dates
import Hledger.Data.Journal
import Hledger.Data.Ledger
import Hledger.Data.MarketPrice
import Hledger.Data.Period
import Hledger.Data.PeriodicTransaction
import Hledger.Data.Posting
import Hledger.Data.RawOptions
import Hledger.Data.StringFormat
import Hledger.Data.Timeclock
import Hledger.Data.Transaction
import Hledger.Data.TransactionModifier
import Hledger.Data.Types
import Hledger.Utils.Test

tests_Data = tests "Data" [
   tests_AccountName
  ,tests_Amount
  ,tests_Journal
  ,tests_Ledger
  ,tests_Posting
  ,tests_StringFormat
  ,tests_Timeclock
  ,tests_Transaction
  ]
